Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
mall/__init__.py | (no function) | 3 | 0 | 0 | 100%
mall/data.py | (no function) | 3 | 0 | 0 | 100%
mall/llm.py | map_call | 13 | 0 | 0 | 100%
mall/llm.py | llm_call | 32 | 4 | 0 | 88%
mall/llm.py | valid_output | 7 | 0 | 0 | 100%
mall/llm.py | build_msg | 4 | 0 | 0 | 100%
mall/llm.py | build_hash | 5 | 0 | 0 | 100%
mall/llm.py | cache_check | 8 | 0 | 0 | 100%
mall/llm.py | cache_record | 8 | 0 | 0 | 100%
mall/llm.py | cache_path | 3 | 0 | 0 | 100%
mall/llm.py | (no function) | 13 | 0 | 0 | 100%
mall/polars.py | MallFrame.__init__ | 2 | 0 | 0 | 100%
mall/polars.py | MallFrame.use | 7 | 0 | 0 | 100%
mall/polars.py | MallFrame.sentiment | 2 | 0 | 0 | 100%
mall/polars.py | MallFrame.summarize | 2 | 0 | 0 | 100%
mall/polars.py | MallFrame.translate | 2 | 0 | 0 | 100%
mall/polars.py | MallFrame.classify | 2 | 0 | 0 | 100%
mall/polars.py | MallFrame.extract | 12 | 1 | 0 | 92%
mall/polars.py | MallFrame.custom | 2 | 2 | 0 | 0%
mall/polars.py | MallFrame.verify | 2 | 0 | 0 | 100%
mall/polars.py | (no function) | 14 | 0 | 0 | 100%
mall/prompt.py | sentiment | 3 | 0 | 0 | 100%
mall/prompt.py | summarize | 2 | 0 | 0 | 100%
mall/prompt.py | translate | 2 | 0 | 0 | 100%
mall/prompt.py | classify | 3 | 0 | 0 | 100%
mall/prompt.py | extract | 15 | 0 | 0 | 100%
mall/prompt.py | verify | 2 | 0 | 0 | 100%
mall/prompt.py | custom | 2 | 2 | 0 | 0%
mall/prompt.py | process_labels | 15 | 0 | 0 | 100%
mall/prompt.py | (no function) | 8 | 0 | 0 | 100%
tests/__init__.py | (no function) | 0 | 0 | 0 | 100%
tests/test_classify.py | test_classify | 4 | 0 | 0 | 100%
tests/test_classify.py | test_classify_dict | 4 | 0 | 0 | 100%
tests/test_classify.py | (no function) | 10 | 1 | 0 | 90%
tests/test_extract.py | test_extract_list | 4 | 0 | 0 | 100%
tests/test_extract.py | test_extract_dict | 4 | 0 | 0 | 100%
tests/test_extract.py | test_extract_one | 4 | 0 | 0 | 100%
tests/test_extract.py | (no function) | 11 | 1 | 0 | 91%
tests/test_sentiment.py | test_sentiment_simple | 5 | 0 | 0 | 100%
tests/test_sentiment.py | sim_sentiment | 3 | 0 | 0 | 100%
tests/test_sentiment.py | test_sentiment_valid | 3 | 0 | 0 | 100%
tests/test_sentiment.py | test_sentiment_valid2 | 3 | 0 | 0 | 100%
tests/test_sentiment.py | test_sentiment_prompt | 4 | 0 | 0 | 100%
tests/test_sentiment.py | (no function) | 13 | 1 | 0 | 92%
tests/test_summarize.py | test_summarize_prompt | 4 | 0 | 0 | 100%
tests/test_summarize.py | test_summarize_max | 4 | 0 | 0 | 100%
tests/test_summarize.py | (no function) | 10 | 1 | 0 | 90%
tests/test_translate.py | test_translate_prompt | 4 | 0 | 0 | 100%
tests/test_translate.py | (no function) | 9 | 1 | 0 | 89%
tests/test_use.py | test_use_init | 4 | 0 | 0 | 100%
tests/test_use.py | test_use_mod1 | 4 | 0 | 0 | 100%
tests/test_use.py | test_use_mod2 | 4 | 0 | 0 | 100%
tests/test_use.py | (no function) | 6 | 0 | 0 | 100%
tests/test_verify.py | test_verify | 4 | 0 | 0 | 100%
tests/test_verify.py | test_verify_yn | 4 | 0 | 0 | 100%
tests/test_verify.py | (no function) | 10 | 1 | 0 | 90%
Total |  | 337 | 15 | 0 | 96%

No items found using the specified filter.